==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/Stacked100LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedLineSeries } from "./StackedLineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedLineSeriesView } from "./StackedLineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100LineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeries, _super);
    function Stacked100LineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100LineSeries.$;
        return _this;
    }
    Stacked100LineSeries.prototype.cq = function () {
        return new Stacked100LineSeriesView(this);
    };
    Stacked100LineSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.abk = a;
    };
    Stacked100LineSeries.prototype.get_aam = function () {
        return true;
    };
    Stacked100LineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.rm(false);
    };
    Stacked100LineSeries.prototype.aa2 = function () {
        _super.prototype.aa2.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zg;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100LineSeries.$t = markType(Stacked100LineSeries, 'Stacked100LineSeries', StackedLineSeries.$, [IStacked100Series_$type]);
    return Stacked100LineSeries;
}(StackedLineSeries));
export { Stacked100LineSeries };
/**
 * @hidden
 */
var Stacked100LineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeriesView, _super);
    function Stacked100LineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100LineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.w1 = Defaults.e;
        }
    };
    Stacked100LineSeriesView.$t = markType(Stacked100LineSeriesView, 'Stacked100LineSeriesView', StackedLineSeriesView.$);
    return Stacked100LineSeriesView;
}(StackedLineSeriesView));
export { Stacked100LineSeriesView };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/Stacked100LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedLineSeries } from "./StackedLineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedLineSeriesView } from "./StackedLineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100LineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeries, _super);
    function Stacked100LineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100LineSeries.$;
        return _this;
    }
    Stacked100LineSeries.prototype.cs = function () {
        return new Stacked100LineSeriesView(this);
    };
    Stacked100LineSeries.prototype.q1 = function (a) {
        _super.prototype.q1.call(this, a);
        this.ab3 = a;
    };
    Stacked100LineSeries.prototype.get_aa4 = function () {
        return true;
    };
    Stacked100LineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.rr(false);
    };
    Stacked100LineSeries.prototype.abl = function () {
        _super.prototype.abl.call(this);
        Stacked100DataPreparer.a(this);
    };
    Stacked100LineSeries.prototype.aba = function (a, b) {
        var c = 0;
        for (var d = 0; d < this.series.count; d++) {
            c += this.series._inner[d].ak.item(b);
        }
        return (this.series._inner[a].ak.item(b) / c) * 100;
    };
    Object.defineProperty(Stacked100LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zq;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100LineSeries.$t = markType(Stacked100LineSeries, 'Stacked100LineSeries', StackedLineSeries.$, [IStacked100Series_$type]);
    return Stacked100LineSeries;
}(StackedLineSeries));
export { Stacked100LineSeries };
/**
 * @hidden
 */
var Stacked100LineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeriesView, _super);
    function Stacked100LineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100LineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.xa = Defaults.e;
        }
    };
    Stacked100LineSeriesView.$t = markType(Stacked100LineSeriesView, 'Stacked100LineSeriesView', StackedLineSeriesView.$);
    return Stacked100LineSeriesView;
}(StackedLineSeriesView));
export { Stacked100LineSeriesView };
